library(dplyr)
library(raster)
library(sf)

### identify moss species in ASPAs ###

# Calculate the sum of presence values for each species
species_presence_sum <- rowSums(moss_spp)

# Identify species not present in any site
species_not_present <- names(species_presence_sum[species_presence_sum >= 1])

### Species not present in ASPAs ###

# Calculate the sum of presence values for each species
species_presence_sum <- rowSums(moss_spp)

# Identify species not present in any site
species_not_present <- names(species_presence_sum[species_presence_sum == 0])

# Print or further process the list of species not present in any site
print(species_not_present)

species_list <- species_not_present


# load species coordinates
df <- read.csv("moss_species_coordinates.csv")

# subset Antarctica Treaty Area
df <- subset(df, LAT < -60) 

subset_data <- df[df$species_name %in% species_list, ]

# load aspas shapefile
areas_shapefile <- st_read("Aspas.shp")

aspa_shp <- areas_shapefile %>%
              st_as_sf() %>%
              mutate(area = st_area(.)) %>%
              st_transform(aspa_pts, crs = antarctica_proj)

aspa_shp <- aspa_shp[,1]


# Distance from points to each raster cell

spp_pts <- SpatialPointsDataFrame(coords = subset_data[c("LONG", "LAT")], data = subset_data,
                                  proj4string = CRS("+proj=longlat +datum=WGS84 +ellps=WGS84 +towgs84=0,0,0"))

# Reproject the to the Antarctic Polar Stereographic projection
antarctica_proj <- CRS("+proj=stere +lat_0=-90 +lon_0=0 +lat_ts=-71 +a=6378273 +b=6356889.449 +units=m +no_defs")
spp_pts <- spTransform(spp_pts, CRSobj = antarctica_proj)

spp_pts <- st_as_sf(spp_pts)


# calculate distances
distance <- st_distance(spp_pts, aspa_shp)

min_distances <- apply(distance, 1, min)

spp_pts$min_distance_to_aspa <- min_distances


# Create a ggplot object
ggplot() +
  # Plotting the protected areas
  #geom_sf(data = aspa_pts, fill = "lightgray") +
  # Adding species points to the plot
  geom_sf(data = spp_pts, aes(color = species_name), shape = 16)


min_distances_per_species <- spp_pts %>%
  group_by(species_name) %>%
  summarise(min_distance = min(min_distance_to_aspa))


####

min_distances_per_species$min_distance <- min_distances_per_species$min_distance/1000

selected_species <- min_distances_per_species %>%
  filter(min_distance < 2.821)

protected <- selected_species$species_name


df <- read.csv("moss_species_coordinates.csv")

df <- subset(df, LAT < -60) #subset Antarctica Treaty Area

prot <- df[df$species_name %in% protected, ]


write.csv(prot, "protected.csv")



un_species <- min_distances_per_species %>%
  filter(min_distance > 2.821)

unprotected <- un_species$species_name

unp <- df[df$species_name %in% unprotected, ]


write.csv(unp, "unprotected.csv")
